/**
 * Language API
 * OCI Language Service solutions can help enterprise customers integrate AI into their products immediately using our proven,
pre-trained and custom models or containers, without a need to set up an house team of AI and ML experts.
This allows enterprises to focus on business drivers and development work rather than AI and ML operations, which shortens the time to market.

 * OpenAPI spec version: 20221001
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { AIServiceLanguageWaiter } from "./aiservicelanguage-waiter";
export declare enum AIServiceLanguageApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class AIServiceLanguageClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": AIServiceLanguageWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new AIServiceLanguageWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): AIServiceLanguageWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): AIServiceLanguageWaiter;
    /**
       * The API returns the detected language and a related confidence score (between 0 and 1).  It supports passing a batch of records.
  * <p>
  [List of supported languages.](https://docs.cloud.oracle.com/iaas/language/using/pretrain-models.htm#lang-detect)
  * <p>
  Limitations:
  * - A batch may have up to 100 records.
  * - A record may be up to 5000 characters long.
  * - The total of characters to process in a request can be up to 20,000 characters.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param BatchDetectDominantLanguageRequest
       * @return BatchDetectDominantLanguageResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/BatchDetectDominantLanguage.ts.html |here} to see how to use BatchDetectDominantLanguage API.
       */
    batchDetectDominantLanguage(batchDetectDominantLanguageRequest: requests.BatchDetectDominantLanguageRequest): Promise<responses.BatchDetectDominantLanguageResponse>;
    /**
       * The API extracts entities in text records. For each entity, its type/subtype and confidence score (between 0 and 1) is returned.  It supports passing a batch of records.
  * <p>
  [List of supported entities.](https://docs.cloud.oracle.com/iaas/language/using/pretrain-models.htm#ner__sup-ner-entity)
  * <p>
  Limitations:
  * - A batch may have up to 100 records.
  * - A record may be up to 5000 characters long.
  * - The total of characters to process in a request can be up to 20,000 characters.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param BatchDetectLanguageEntitiesRequest
       * @return BatchDetectLanguageEntitiesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/BatchDetectLanguageEntities.ts.html |here} to see how to use BatchDetectLanguageEntities API.
       */
    batchDetectLanguageEntities(batchDetectLanguageEntitiesRequest: requests.BatchDetectLanguageEntitiesRequest): Promise<responses.BatchDetectLanguageEntitiesResponse>;
    /**
       * The API extracts key-phrases in text records. For each key-phrase, a score (between 0 and 1) is returned that highlights the importance of the key-phrase in the context of the text.  It supports passing a batch of records.
  * <p>
  Limitations:
  * - A batch may have up to 100 records.
  * - A record may be up to 5000 characters long.
  * - The total of characters to process in a request can be up to 20,000 characters.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param BatchDetectLanguageKeyPhrasesRequest
       * @return BatchDetectLanguageKeyPhrasesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/BatchDetectLanguageKeyPhrases.ts.html |here} to see how to use BatchDetectLanguageKeyPhrases API.
       */
    batchDetectLanguageKeyPhrases(batchDetectLanguageKeyPhrasesRequest: requests.BatchDetectLanguageKeyPhrasesRequest): Promise<responses.BatchDetectLanguageKeyPhrasesResponse>;
    /**
       * The API extracts pii entities in text records. For each entity, its type and confidence score (between 0 and 1) is returned.  It supports passing a batch of records.
  * <p>
  Limitations:
  * - A batch may have up to 100 records.
  * - A record may be up to 5000 characters long.
  * - The total of characters to process in a request can be up to 20,000 characters.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param BatchDetectLanguagePiiEntitiesRequest
       * @return BatchDetectLanguagePiiEntitiesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/BatchDetectLanguagePiiEntities.ts.html |here} to see how to use BatchDetectLanguagePiiEntities API.
       */
    batchDetectLanguagePiiEntities(batchDetectLanguagePiiEntitiesRequest: requests.BatchDetectLanguagePiiEntitiesRequest): Promise<responses.BatchDetectLanguagePiiEntitiesResponse>;
    /**
       * The API extracts aspect-based and sentence level sentiment in text records.
  * <p>
  For aspect-based sentiment analysis, a set of aspects and their respective sentiment is returned for each record. Similarly, for sentence-level sentiment analysis, the sentiment is returned at the sentence level.
  * <p>
  For sentiment analysis, confidence scores are provided for each of the classes (positive, negative, neutral and mixed).
  * <p>
  Learn more about sentiment analysis [here](https://docs.cloud.oracle.com/iaas/language/using/pretrain-models.htm#sentiment).
  * <p>
  Limitations:
  *  - A batch may have up to 100 records.
  *  - A record may be up to 5000 characters long.
  *  - The total of characters to process in a request can be up to 20,000 characters.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param BatchDetectLanguageSentimentsRequest
       * @return BatchDetectLanguageSentimentsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/BatchDetectLanguageSentiments.ts.html |here} to see how to use BatchDetectLanguageSentiments API.
       */
    batchDetectLanguageSentiments(batchDetectLanguageSentimentsRequest: requests.BatchDetectLanguageSentimentsRequest): Promise<responses.BatchDetectLanguageSentimentsResponse>;
    /**
       * The API automatically classifies text into a set of pre-determined classes and sub-classes. A single class/subclass is returned for each record classified.
  * <p>
  It supports passing a batch of records.
  * <p>
  Learn more about text classification [here](https://docs.cloud.oracle.com/iaas/language/using/pretrain-models.htm#text-class).
  * <p>
  Limitations:
  * - A batch may have up to 100 records.
  * - A record may be up to 5000 characters long.
  * - The total of characters to process in a request can be up to 20,000 characters.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param BatchDetectLanguageTextClassificationRequest
       * @return BatchDetectLanguageTextClassificationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/BatchDetectLanguageTextClassification.ts.html |here} to see how to use BatchDetectLanguageTextClassification API.
       */
    batchDetectLanguageTextClassification(batchDetectLanguageTextClassificationRequest: requests.BatchDetectLanguageTextClassificationRequest): Promise<responses.BatchDetectLanguageTextClassificationResponse>;
    /**
     * Translate text to other language over pre-deployed model.
     * Use state of the art neural machine translation to translate text between more than 15 languages.
     * Limitations:
     *   - A batch may have up to 100 records.
     *   - A record may be up to 5000 characters long.
     *   - The total of characters to process in a request can be up to 20,000 characters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param BatchLanguageTranslationRequest
     * @return BatchLanguageTranslationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/BatchLanguageTranslation.ts.html |here} to see how to use BatchLanguageTranslation API.
     */
    batchLanguageTranslation(batchLanguageTranslationRequest: requests.BatchLanguageTranslationRequest): Promise<responses.BatchLanguageTranslationResponse>;
    /**
     * Moves a Endpoint into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeEndpointCompartmentRequest
     * @return ChangeEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ChangeEndpointCompartment.ts.html |here} to see how to use ChangeEndpointCompartment API.
     */
    changeEndpointCompartment(changeEndpointCompartmentRequest: requests.ChangeEndpointCompartmentRequest): Promise<responses.ChangeEndpointCompartmentResponse>;
    /**
     * Moves a Model into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeModelCompartmentRequest
     * @return ChangeModelCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ChangeModelCompartment.ts.html |here} to see how to use ChangeModelCompartment API.
     */
    changeModelCompartment(changeModelCompartmentRequest: requests.ChangeModelCompartmentRequest): Promise<responses.ChangeModelCompartmentResponse>;
    /**
     * Moves a Project into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeProjectCompartmentRequest
     * @return ChangeProjectCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ChangeProjectCompartment.ts.html |here} to see how to use ChangeProjectCompartment API.
     */
    changeProjectCompartment(changeProjectCompartmentRequest: requests.ChangeProjectCompartmentRequest): Promise<responses.ChangeProjectCompartmentResponse>;
    /**
     * Creates a new endpoint and deploy the trained model
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateEndpointRequest
     * @return CreateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/CreateEndpoint.ts.html |here} to see how to use CreateEndpoint API.
     */
    createEndpoint(createEndpointRequest: requests.CreateEndpointRequest): Promise<responses.CreateEndpointResponse>;
    /**
     * Creates a new model for training and train the model with date provided.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelRequest
     * @return CreateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/CreateModel.ts.html |here} to see how to use CreateModel API.
     */
    createModel(createModelRequest: requests.CreateModelRequest): Promise<responses.CreateModelResponse>;
    /**
     * Creates a new Project.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateProjectRequest
     * @return CreateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/CreateProject.ts.html |here} to see how to use CreateProject API.
     */
    createProject(createProjectRequest: requests.CreateProjectRequest): Promise<responses.CreateProjectResponse>;
    /**
     * Deletes a provisioned endpoint resource by identifier. This operation fails with a 409 error unless all associated resources are in a DELETED state. You must delete all associated resources before deleting a model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteEndpointRequest
     * @return DeleteEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DeleteEndpoint.ts.html |here} to see how to use DeleteEndpoint API.
     */
    deleteEndpoint(deleteEndpointRequest: requests.DeleteEndpointRequest): Promise<responses.DeleteEndpointResponse>;
    /**
     * Deletes a provisioned model resource by identifier. This operation fails with a 409 error unless all associated resources are in a DELETED state. You must delete all associated resources before deleting a model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelRequest
     * @return DeleteModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DeleteModel.ts.html |here} to see how to use DeleteModel API.
     */
    deleteModel(deleteModelRequest: requests.DeleteModelRequest): Promise<responses.DeleteModelResponse>;
    /**
     * Deletes a Project resource by identifier. This operation fails with a 409 error unless all associated resources (models deployments or data assets) are in a DELETED state. You must delete all associated resources before deleting a project.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteProjectRequest
     * @return DeleteProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DeleteProject.ts.html |here} to see how to use DeleteProject API.
     */
    deleteProject(deleteProjectRequest: requests.DeleteProjectRequest): Promise<responses.DeleteProjectResponse>;
    /**
       * **Deprecated**: This API will be retired Tuesday, 10 Oct 2023 00:00:00 GMT.
  * We recommend you replace this API with the batch API, [BatchDetectDominantLanguage](https://docs.cloud.oracle.com/iaas/api/#/en/language/20221001/BatchDetectDominantLanguage/BatchDetectDominantLanguage).
  * <p>
  The DetectDominantLanguage API returns the detected language and a related confidence score (between 0 and 1).
  * <p>
  [List of supported languages](https://docs.cloud.oracle.com/iaas/language/using/pretrain-models.htm#lang-detect)
  * <p>
  Limitations:
  * - A record may be up to 1000 characters long.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DetectDominantLanguageRequest
       * @return DetectDominantLanguageResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DetectDominantLanguage.ts.html |here} to see how to use DetectDominantLanguage API.
       */
    detectDominantLanguage(detectDominantLanguageRequest: requests.DetectDominantLanguageRequest): Promise<responses.DetectDominantLanguageResponse>;
    /**
       * **Deprecated**: This API will be retired Tuesday, 10 Oct 2023 00:00:00 GMT.
  * We recommend you replace this API with the batch API, [BatchDetectLanguageEntities](https://docs.cloud.oracle.com/iaas/api/#/en/language/20221001/BatchDetectLanguageEntities/BatchDetectLanguageEntities).
  * <p>
  The DetectLanguageEntities API extracts entities in text records. For each entity, its type and confidence score (between 0 and 1) is returned.
  * <p>
  Limitations:
  * - A text may be up to 1000 characters long.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DetectLanguageEntitiesRequest
       * @return DetectLanguageEntitiesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DetectLanguageEntities.ts.html |here} to see how to use DetectLanguageEntities API.
       */
    detectLanguageEntities(detectLanguageEntitiesRequest: requests.DetectLanguageEntitiesRequest): Promise<responses.DetectLanguageEntitiesResponse>;
    /**
       * **Deprecated**: This API will be retired Tuesday, 10 Oct 2023 00:00:00 GMT.
  * We recommend you replace this API with the batch API, [BatchDetectLanguageKeyPhrases](https://docs.cloud.oracle.com/iaas/api/#/en/language/20221001/BatchDetectLanguageKeyPhrases/BatchDetectLanguageKeyPhrases).
  * <p>
  The DetectLanguageKeyPhrases API extracts key-phrases in text records. For each key-phrase, a score (between 0 and 1) is returned that highlights the importance of the key-phrase in the context of the text.
  * <p>
  Limitations:
  * - A record may be up to 1000 characters long.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DetectLanguageKeyPhrasesRequest
       * @return DetectLanguageKeyPhrasesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DetectLanguageKeyPhrases.ts.html |here} to see how to use DetectLanguageKeyPhrases API.
       */
    detectLanguageKeyPhrases(detectLanguageKeyPhrasesRequest: requests.DetectLanguageKeyPhrasesRequest): Promise<responses.DetectLanguageKeyPhrasesResponse>;
    /**
       * **Deprecated**: This API will be retired Tuesday, 10 Oct 2023 00:00:00 GMT.
  * We recommend you replace this API with the batch API, [BatchDetectLanguageSentiments](https://docs.cloud.oracle.com/iaas/api/#/en/language/20221001/BatchDetectLanguageSentiments/BatchDetectLanguageSentiments).
  * <p>
  The DetectLanguageSentiments API extracts aspect-based in text records.
  * <p>
  For aspect-based sentiment analysis, a set of aspects and their respective sentiment is returned.
  * <p>
  For sentiment analysis, confidence scores are provided for each of the classes (positive, negative, neutral).
  * <p>
  Learn more about sentiment analysis [here](https://docs.cloud.oracle.com/iaas/language/using/pretrain-models.htm#sentiment).
  * <p>
  Limitations:
  *  - A record may be up to 1000 characters long.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DetectLanguageSentimentsRequest
       * @return DetectLanguageSentimentsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DetectLanguageSentiments.ts.html |here} to see how to use DetectLanguageSentiments API.
       */
    detectLanguageSentiments(detectLanguageSentimentsRequest: requests.DetectLanguageSentimentsRequest): Promise<responses.DetectLanguageSentimentsResponse>;
    /**
       * **Deprecated**: This API will be retired Tuesday, 10 Oct 2023 00:00:00 GMT.
  * We recommend you replace this API with the batch API, [BatchDetectLanguageTextClassification](https://docs.cloud.oracle.com/iaas/api/#/en/language/20221001/BatchDetectLanguageTextClassification/BatchDetectLanguageTextClassification).
  * <p>
  The DetectLanguageTextClassification API automatically classifies text into a set of pre-determined classes and sub-classes. A single class/subclass is returned for each record classified.
  * <p>
  Learn more about text classification [here](https://docs.cloud.oracle.com/iaas/language/using/pretrain-models.htm#text-class).
  * <p>
  Limitations:
  * - A record may be up to 1000 characters long.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DetectLanguageTextClassificationRequest
       * @return DetectLanguageTextClassificationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/DetectLanguageTextClassification.ts.html |here} to see how to use DetectLanguageTextClassification API.
       */
    detectLanguageTextClassification(detectLanguageTextClassificationRequest: requests.DetectLanguageTextClassificationRequest): Promise<responses.DetectLanguageTextClassificationResponse>;
    /**
     * Gets an endpoint by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetEndpointRequest
     * @return GetEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/GetEndpoint.ts.html |here} to see how to use GetEndpoint API.
     */
    getEndpoint(getEndpointRequest: requests.GetEndpointRequest): Promise<responses.GetEndpointResponse>;
    /**
     * Gets a model by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelRequest
     * @return GetModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/GetModel.ts.html |here} to see how to use GetModel API.
     */
    getModel(getModelRequest: requests.GetModelRequest): Promise<responses.GetModelResponse>;
    /**
     * Gets a Project by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetProjectRequest
     * @return GetProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/GetProject.ts.html |here} to see how to use GetProject API.
     */
    getProject(getProjectRequest: requests.GetProjectRequest): Promise<responses.GetProjectResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of Endpoints.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListEndpointsRequest
     * @return ListEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ListEndpoints.ts.html |here} to see how to use ListEndpoints API.
     */
    listEndpoints(listEndpointsRequest: requests.ListEndpointsRequest): Promise<responses.ListEndpointsResponse>;
    /**
     * Get a (paginated) list of evaluation results for a given model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListEvaluationResultsRequest
     * @return ListEvaluationResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ListEvaluationResults.ts.html |here} to see how to use ListEvaluationResults API.
     */
    listEvaluationResults(listEvaluationResultsRequest: requests.ListEvaluationResultsRequest): Promise<responses.ListEvaluationResultsResponse>;
    /**
     * Returns a list of models.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelsRequest
     * @return ListModelsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ListModels.ts.html |here} to see how to use ListModels API.
     */
    listModels(listModelsRequest: requests.ListModelsRequest): Promise<responses.ListModelsResponse>;
    /**
     * Returns a list of  Projects.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListProjectsRequest
     * @return ListProjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ListProjects.ts.html |here} to see how to use ListProjects API.
     */
    listProjects(listProjectsRequest: requests.ListProjectsRequest): Promise<responses.ListProjectsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Update the Endpoint identified by the id
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateEndpointRequest
     * @return UpdateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/UpdateEndpoint.ts.html |here} to see how to use UpdateEndpoint API.
     */
    updateEndpoint(updateEndpointRequest: requests.UpdateEndpointRequest): Promise<responses.UpdateEndpointResponse>;
    /**
     * Updates the model
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelRequest
     * @return UpdateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/UpdateModel.ts.html |here} to see how to use UpdateModel API.
     */
    updateModel(updateModelRequest: requests.UpdateModelRequest): Promise<responses.UpdateModelResponse>;
    /**
     * Updates the Project
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateProjectRequest
     * @return UpdateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.50.3/ailanguage/UpdateProject.ts.html |here} to see how to use UpdateProject API.
     */
    updateProject(updateProjectRequest: requests.UpdateProjectRequest): Promise<responses.UpdateProjectResponse>;
}
